#
# spec file for package build-helper-maven-plugin
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global oldname maven-plugin-build-helper
Name:           build-helper-maven-plugin
Version:        3.6.0
Release:        1.4
Summary:        Build Helper Maven Plugin
License:        MIT
URL:            https://www.mojohaus.org/build-helper-maven-plugin/
Source0:        https://github.com/mojohaus/%{name}/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  maven-local
BuildRequires:  mvn(org.apache-extras.beanshell:bsh)
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-annotations)
BuildRequires:  mvn(org.apache.maven.plugins:maven-invoker-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven.shared:file-management) >= 3.1.0
BuildRequires:  mvn(org.apache.maven:maven-core)
BuildRequires:  mvn(org.apache.maven:maven-plugin-api)
BuildRequires:  mvn(org.codehaus.mojo:mojo-parent:pom:)
BuildRequires:  mvn(org.codehaus.plexus:plexus-utils)
BuildRequires:  mvn(org.slf4j:slf4j-api)
Provides:       %{oldname} = %{version}
Obsoletes:      %{oldname} < %{version}
BuildArch:      noarch

%description
This plugin contains various small independent goals to assist with
Maven build lifecycle.

%package javadoc
Summary:        API documentation for %{name}
Provides:       %{oldname}-javadoc = %{version}
Obsoletes:      %{oldname}-javadoc = %{version}

%description javadoc
This package provides %{summary}.

%prep
%setup -q
%pom_remove_plugin :maven-checkstyle-plugin

%build
%{mvn_build} -f -- -Dsource=8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE.txt
%doc README.md

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt

%changelog
* Tue Jun 11 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to upsteam version 3.6.0
  * New features and improvements
    + Provide the Mojos logger as variable in the Interpreter context
    + Get rid of ArtifactRepository - ${localRepository}
    + Added a property name to the "sources" parameter for CLI usage
    + Add skipIfMissing flag
    + Add skip flags
    + Deprecate maven-version goal
    + Deprecate remove-project-artifact goal
    + Parallel execution of uptodate-properties
  * Bug Fixes
    + Fixes #108, released-version does not detect version if maven
    repository is not configured to look for snapshot
    + Add missing whitespace to output of reserve-network-port
    + Use UTF-8 for the pom
* Tue Jun 11 2024 Fridrich Strba <fstrba@suse.com>
- Rename package:
  maven-plugin-build-helper -> build-helper-maven-plugin
  + corresponds to the source name
* Thu Oct 26 2023 Fridrich Strba <fstrba@suse.com>
- Build javadoc with source level 8
* Tue Sep  8 2020 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.2.0
  * Integrated pull requests:
    + Set a property based on the maven.build.timestamp
    + rootlocation does not correctly work
    + Add profile to avoid showing warnings for maven plugin
    plugin goals not supported in m2e
    + Site: Properly showing 'value' tag on regex-properties usage
    page
    + Integration test reserve-ports-with-urls fails on windows
    + IllegalArgumentException when using goal released-version with
    maven 3.6.2
    + NPE in 3.1.0-SNAPSHOT when no qualifier is present
    + parse-version goal fails when build number is greater than
    Integer.MAX_VALUE enhancement
    + Create directory before writing file in reserve-network-port
    bug
    + released-version does not allow access to the build number
    + Qualifier Prefix
* Fri Apr  5 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of maven-plugin-build-helper 1.9.1
